{ pkgs, osConfig, ... }:
let
  withCuda = if (osConfig.system.name == "gunter") then true else false;
in
{
  imports = [
    ./zoom.nix
    ./tacl.nix
  ];
  home.packages = with pkgs; [
    # CLI utils
    age
    bat
    bzip2
    chromium
    croc
    devenv
    distrobox
    dust
    easyeffects
    eza
    fd
    ffmpeg
    file
    fzf
    grimblast
    ijq
    jellyfin-media-player
    jq
    kitty
    kubectl
    lazygit
    lf
    ncdu
    nvd
    nurl
    nwg-look
    most
    pinentry
    pulseaudio
    pulsemixer
    rbw
    restic
    ripgrep
    sidequest
    sops
    sshfs
    step-cli
    tea
    tldr
    tokei
    unzip
    wtype

    # Non-CLI stuff
    alacritty
    discord
    feh
    krita
    mpv
    mumble
    pamixer
    pwvucontrol
    prismlauncher
    rofi-rbw-wayland
    spotify
    virt-manager
    vmware-horizon-client
    yt-dlp

    # Go stuff
    go
    gopls
    delve

    # Py stuff
    (python312.withPackages (
      p: with p; [
        requests
        ipython
      ]
    ))
    uv
    ruff

    # rust stuff
    rustc
    cargo
    rust-analyzer

    # Homemade shit
    ghettoptt
    huecli
    nixprstatus

    # Stuff with overrides
    (btop.override { cudaSupport = withCuda; })

    # Extract logcli from grafana-loki
    (pkgs.linkFarm "logcli" [
      {
        name = "bin/logcli";
        path = "${pkgs.grafana-loki}/bin/logcli";
      }
    ])
    (lutris.override {
      extraLibraries = pkgs: [
        nspr
        xorg.libXdamage
      ];
    })
  ];
}
